#!/usr/env/env python

from exp_run import FreeBSD11, FreeBSD12, FreeBSD13
from plumbum import FG, local
from plumbum.machines.paramiko_machine import ParamikoMachine

PORTSDIR = "/usr/ports"
PKGDIR = "/usr/local/poudriere/data/packages"

def main():
    freefall = "dbn@freefall.freebsd.org"
    
    with ParamikoMachine("dbn.westeurope.cloudapp.azure.com", "root", connect_timeout=None) as remote:
        make = remote["make"]
        ssh = remote["ssh"]
        ssh_add = remote["ssh-add"]
        ssh_agent = remote["ssh-agent"]
        scp = remote["scp"]
        
        portsdir = remote.path(PORTSDIR)
        pkgdir = remote.path(PKGDIR)
        
        agent = ssh_agent("-s")
        sock = agent.split(";")[0].split("=")[1]
        pid = agent.split(";")[2].split("=")[1]
        remote.env["SSH_AUTH_SOCK"] = sock
        remote.env["SSH_AGENT_PID"] = pid
        try:
            with remote.tempdir() as tmpdir:
                id = tmpdir / "id_ed25519"
                id.touch()
                id.chmod(0o400)
                id.write(local.path("~/.ssh/id_ed25519").read())
                ssh_add(id)
            for port in ("emulators/i386-wine", "emulators/i386-wine-devel"):
                pkgversion = make("-C", portsdir / port, "-V", "PKGVERSION", "ARCH=i386").rstrip()
                portversion = make("-C", portsdir / port, "-V", "PKGVERSION", "ARCH=amd64").rstrip()
                if pkgversion != portversion:
                    for jail in (FreeBSD11.i386, FreeBSD12.i386, FreeBSD13.i386):
                        repodir = "public_distfiles/repos/wine/freebsd:%s:x86:64/" % jail.version.split(".")[0]
                        ssh(freefall, "mkdir", "-p", repodir)
                        pkgname = make("-C", portsdir / port, "-V", "PKGNAME", "ARCH=i386").rstrip()
                        pkgpath = pkgdir / ("%s-default-wine" % jail) / "All" / ("%s.txz" % pkgname)
                        scp(pkgpath, "%s:%s" % (freefall, repodir))
        finally:
            ssh_agent("-k")

if __name__ == "__main__":
    main()
